Index: vlc-0.9.8a\modules\access\rtmp\access.c
===================================================================
--- vlc-0.9.8a\modules\access\rtmp\access.c	(revision 2718)
+++ vlc-0.9.8a\modules\access\rtmp\access.c	(revision 2719)
@@ -78,8 +78,8 @@
 static int Open( vlc_object_t *p_this )
 {
     access_t *p_access = (access_t *) p_this;
-    access_sys_t *p_sys;
-    char *psz, *p; 
+    access_sys_t *p_sys = NULL;
+    char *psz = NULL, *p = NULL; 
     int length_path, length_media_name;
     int i;
 
@@ -93,12 +93,12 @@
 
     /* Parse URI - remove spaces */
     p = psz = strdup( p_access->psz_path );
-    while( (p = strchr( p, ' ' )) != NULL )
+    while( p = strchr( p, ' ' ) )
         *p = '+';
     vlc_UrlParse( &p_sys->p_thread->url, psz, 0 );
     free( psz );
 
-    if( p_sys->p_thread->url.psz_host == NULL
+    if( !p_sys->p_thread->url.psz_host
         || *p_sys->p_thread->url.psz_host == '\0' )
     {
         msg_Warn( p_access, "invalid host" );
@@ -108,7 +108,7 @@
     if( p_sys->p_thread->url.i_port <= 0 )
         p_sys->p_thread->url.i_port = 1935;
 
-    if( p_sys->p_thread->url.psz_path == NULL )
+    if( !p_sys->p_thread->url.psz_path)
     {
         msg_Warn( p_access, "invalid path" );
         goto error;
@@ -180,7 +180,7 @@
         p_sys->active = 0;
 
         p_fd_listen = net_ListenTCP( p_access, p_sys->p_thread->url.psz_host, p_sys->p_thread->url.i_port );
-        if( p_fd_listen == NULL )
+        if( !p_fd_listen)
         {
             msg_Err( p_access, "cannot listen to %s port %i", p_sys->p_thread->url.psz_host, p_sys->p_thread->url.i_port );
             goto error2;
@@ -279,9 +279,13 @@
 
     for( i = 0; i < 64; i++ ) /* RTMP_HEADER_STREAM_INDEX_MASK */
     {
-        if( p_sys->p_thread->rtmp_headers_recv[i].body != NULL )
+        if( p_sys->p_thread->rtmp_headers_recv[i].body )
         {
+            if(p_sys->p_thread->rtmp_headers_recv[i].body->body)
+        {
             free( p_sys->p_thread->rtmp_headers_recv[i].body->body );
+            }
+            
             free( p_sys->p_thread->rtmp_headers_recv[i].body );
         }
     }
@@ -308,10 +312,8 @@
     rtmp_packet_t *rtmp_packet;
     uint8_t *tmp_buffer;
     ssize_t i_ret;
-    size_t i_len_tmp;
+    size_t i_len_tmp = 0;
 
-    i_len_tmp = 0;
-
     while( i_len_tmp < i_len )
     {
         if( p_sys->p_thread->result_stop || p_access->info.b_eof || !vlc_object_alive (p_access) )
@@ -338,7 +340,7 @@
             else
             {
                 p_sys->flv_packet = block_FifoGet( p_sys->p_thread->p_fifo_input );
-                if( p_sys->flv_packet == NULL )
+                if( !p_sys->flv_packet )
                     continue; /* Forced wake-up */
             }
 
@@ -426,10 +428,22 @@
  *****************************************************************************/
 static int Seek( access_t *p_access, int64_t i_pos )
 {
-    VLC_UNUSED( p_access );
-    VLC_UNUSED( i_pos );
-// delete comment by renh begin
-    msg_Warn ( p_access, "Seek to %lld", i_pos);
+    int filePercent = p_access->info.i_size * i_pos / p_access->info.i_seekpoint;
+    uint8_t* p_buffer = new uint8_t[filePercent];
+    ssize_t size;
+	
+    if((size = Read(p_access, p_buffer, filePercent )) == -1)
+    {
+    	  msg_Err( p_access, "Seek failed." );
+	  return VLC_EGENERIC;
+    }else
+    {
+    	return size;
+    }
+/*   VLC_UNUSED( p_access );
+//   VLC_UNUSED( i_pos );
+//   comment by renhao for seek :begin
+//    msg_Warn ( p_access, "Seek to %lld", i_pos);
     switch( rtmp_seek( p_access, i_pos ) )
     {
         case -1:
@@ -440,8 +454,10 @@
             msg_Err( p_access, "You should not be here" );
             abort();
     }
-// end
+
     return VLC_EGENERIC;
+    // comment by renhao for seek :end
+*/
 }
 
 /*****************************************************************************
@@ -517,7 +533,7 @@
     while( vlc_object_alive (p_thread) )
     {
         rtmp_packet = rtmp_read_net_packet( p_thread );
-        if( rtmp_packet != NULL )
+        if( rtmp_packet )
         {
             if( rtmp_packet->content_type < 0x01 /* RTMP_CONTENT_TYPE_CHUNK_SIZE */
                 || rtmp_packet->content_type > 0x14 ) /* RTMP_CONTENT_TYPE_INVOKE */
